exceptiontools.AssignabilityError
=================================

.. inheritance-diagram:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.AssignabilityError.AssignabilityError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
